#!/usr/bin/env python
###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###

import argparse
import logging
import os
import requests
import urllib2


'''
Base class for all the Boundary CLI commands
'''
class ApiCall():

  def __init__(self):
    self.message = None
    self.path = None
    self.apihost = "premium-api.boundary.com"
    self.email = None
    self.apitoken = None
    self.scheme = "https"
    self.path = None
    self.url_parameters = None
    self.method = "GET"
    self.data = None
    self.result = None
    
    # Construct a dictionary with each of the HTTP methods that we support
    self.methods = {"DELETE": self.doDelete,"GET": self.doGet,"POST": self.doPost,"PUT": self.doPut}
      
  def setErrorMessage(self,message):
        self.message = message
      
  def getUrlParameters(self):
    urlParameters = ""
    if self.url_parameters != None:
        urlParameters = "?"
        values = self.url_parameters
        first = True
        for key in values:
            if first == True:
                first = False
            else:
                urlParameters = urlParameters + "&"
            urlParameters = urlParameters + "{0}={1}".format(key,values[key])
    return urlParameters

  def doGet(self):
    '''
    HTTP Get Request
    '''
    return requests.get(self.url,auth=(self.email,self.apitoken),data=self.data)

  def doDelete(self):
    '''
    HTTP Delete Request
    '''
    return requests.delete(self.url,auth=(self.email,self.apitoken),data=self.data)

  def doPost(self):
    return requests.post(self.url,auth=(self.email,self.apitoken),data=self.data)

  def doPut(self):
    '''
    HTTP Put Request
    '''
    return requests.put(self.url,auth=(self.email,self.apitoken),data=self.data)

  def callAPI(self):
    '''
    Make an API call to get the metric definition
    '''

    self.url = "{0}://{1}/{2}{3}".format(self.scheme,self.apihost,self.path,self.getUrlParameters())
    logging.debug(self.url)

    self.result = self.methods[self.method]()
    if self.result.status_code != urllib2.httplib.OK:
        logging.error(self.url)
        if self.data != None:
            logging.error(self.data)
        logging.error(self.result)
      
  def handleResults(self,result):
    '''
    Call back function to be implemented by the CLI.
    Default is to just print the results to standard out
    '''
    print(result.text)
    
    
    




#!/usr/bin/python
##
## Copyright 2014-2015 Boundary, Inc.
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##     http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
##

'''
Exports metrics from a Boundary account with the ability to filter on metric name
'''
from api_cli import ApiCli
import json
import logging
import re
import sys

class MetricExport(ApiCli):

    def __init__(self):
        '''
        Initialize the instance
        '''
        ApiCli.__init__(self)
        self.path = "v1/metrics"
        self.metrics = None
        self.patterns = None
        self.filter_expression = None

    def getDescription(self):
        return 'Export the metric definitions from a Boundary account'

    def addArguments(self):
        ApiCli.addArguments(self)
        self.parser.add_argument('-p','--pattern',metavar='pattern',dest='patterns',action='store',
                                 help='regular expression pattern to use search the name of the metric')
        
    def getArguments(self):
        ApiCli.getArguments(self)
        
        if self.args.patterns:
            self.filter_expression = re.compile(self.args.patterns)

    def extractFields(self, metric):
        '''
        Extract only the required fields for the create/update API call
        '''
        m = {}
        try:
            m['name'] = metric['name']
            m['description'] = metric['description']
            m['displayName'] = metric['displayName']
            m['displayNameShort'] = metric['displayNameShort']
            m['unit'] = metric['unit']
            m['defaultAggregate'] = metric['defaultAggregate']
            m['defaultResolutionMS'] = metric['defaultResolutionMS']
            m['isDisabled'] = metric['isDisabled']
        except KeyError as e:
            logging.error("Missing field \"" + e.message + "\" in result")
            sys.exit(1)

        return m

    def extract(self, metrics):
        '''
         Extract required fields
        '''
        new_metrics = []
        for m in metrics:
            new_metrics.append(self.extractFields(m))
        return new_metrics

    def filter(self):
        '''
         Apply the criteria to filter out on the metrics required
        '''
        new_metrics = []
        if self.filter_expression != None:
            metrics = self.metrics['result']
            for m in metrics:
                if self.filter_expression.search(m['name']):
                    new_metrics.append(m)
        else:
            new_metrics = self.metrics['result']

        self.metrics['result'] = self.extract(new_metrics)

    def handleResults(self,result):
        '''
        Call back function to be implemented by the CLI.
        '''
        self.metrics = json.loads(result.text)
        self.filter()
        out = json.dumps(self.metrics, sort_keys=True, indent=4,separators=(',', ': '))
        print out






            



###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###
'''
'''
import json
from api_cli import ApiCli
from user_get import UserGet

class SourceList (ApiCli):
     
    def __init__(self):
        ApiCli.__init__(self)
        self.path = "v1/account"
        self.method = "GET"
        self.projectId = None
        
    def addArguments(self):
        ApiCli.addArguments(self)
        
    def getArguments(self):
        ApiCli.getArguments(self)
        user = UserGet()
        user.apihost = self.apihost
        user.apitoken = self.apitoken
        user.email = self.email
        user.validateAndRun()
        if self.result != None:
            userInfo = json.loads(self.result.text)
            print(userInfo)
            self.projectId = userInfo.result.projectId
            
        self.path = "account/{0}/sourcetypes".format(self.projectId)
            
    def validateArguments(self):
        if self.projectId == None:
            self.setErrorMessage("Unable to get account")
            return False

        return ApiCli.validateArguments(self)
        
    def getDescription(self):
        return "Lists the plugins in a Boundary account"
    


###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###
from api_cli import ApiCli

class MetricCreate (ApiCli):
     
    def __init__(self):
        ApiCli.__init__(self)
        self.method = "PUT"
        
        self.metricName = None
        self.displayName = None
        self.displayNameShort = None
        self.description = None
        self.aggregate = None
        self.unit = None
        self.resolution = None
        self.isDisabled = False
        
    def addArguments(self):
        ApiCli.addArguments(self)
        self.parser.add_argument('-n', '--metric-name', dest='metricName',action='store',required=True,metavar='metric_name',help='Metric identifier')
        self.parser.add_argument('-d', '--display-name', dest='displayName',action='store',metavar='display_name',help='Metric display name')
        self.parser.add_argument('-s', '--display-name-short', dest='displayNameShort',action='store',metavar='display_short_name',help='Metric short display name')
        self.parser.add_argument('-i', '--description', dest='description',action='store',metavar='description',help='Metric description')
        self.parser.add_argument('-g', '--aggregate', dest='aggregate',action='store',choices=['sum','avg','max','min'],help='Metric default aggregate')
        self.parser.add_argument('-u', '--unit', dest='unit',action='store',choices=['percent','number','bytecount','duration'],help='Metric unit')
        self.parser.add_argument('-r', '--resolution', dest='resolution',action='store',metavar='resolution',help='Metric default resolution')
        self.parser.add_argument('-x', '--is-disabled',dest='isDisabled',action='store_true',help='disable metric')
        
    def getArguments(self):
        '''
        Extracts the specific arguments of this CLI
        '''
        ApiCli.getArguments(self)
        if self.args.metricName != None:
            self.metricName = self.args.metricName
            
        if self.args.displayName != None:
            self.displayName = self.args.displayName
        else:
            self.displayName = self.metricName
                        
        if self.args.displayNameShort != None:
            self.displayNameShort = self.args.displayNameShort
        else:
            self.displayNameShort = self.metricName
            
        if self.args.description != None:
            self.description = self.args.description
        else:
            self.description = self.metricName
                    
        if self.args.aggregate != None:
            self.aggregate = self.args.aggregate
        else:
            self.aggregate = "ave"
            
        if self.args.unit != None:
            self.unit = self.args.unit
        else:
            self.unit = "number"
            
        if self.args.resolution != None:
            self.resolution = self.args.resolution
        else:
            self.resolution = 1000
            
        if self.args.isDisabled != None:
            self.isDisabled = self.args.isDisabled
       
        self.data = {'name': self.metricName,
                    'displayName': self.displayName,
                    'displayNameShort': self.displayNameShort,
                    'description': self.description,
                    'defaultAggregate': self.aggregate,
                    'unit': self.unit,
                    'defaultResolutionMS': self.resolution,
                    'isDisabled': self.isDisabled}
        self.path = "v1/metrics/{0}".format(self.metricName)
        self.headers = {'Content-Type': 'application/json'}

    
    def validateArguments(self):
        return ApiCli.validateArguments(self)
         
    def getDescription(self):
        return "Creates a new metric definition in an Boundary account"
    


###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###
from api_cli import ApiCli

class HostGroupModify (ApiCli):
     
    def __init__(self,update):
        ApiCli.__init__(self)
        self.update = update
        if self.update == True:
            self.method = "PUT"
        else:
            self.method = "POST"
        self.path="v1/hostgroups"
        self.sources = None
        
        self.hostGroupName = ""
        
    def addArguments(self):
        ApiCli.addArguments(self)
        self.parser.add_argument('-n', '--host-group-name', dest='hostGroupName',action='store',required=True,metavar="host_group_name",help='Host group name')
        self.parser.add_argument('-s', '--sources', dest='sources',action='store',required=True,metavar='sources',help='Comma separated sources to add to the host group. If empty adds all hosts.')
        
    def getArguments(self):
        '''
        Extracts the specific arguments of this CLI
        '''
        ApiCli.getArguments(self)
        
        # Get the host group name
        if self.args.hostGroupName != None:
            self.hostGroupName = self.args.hostGroupName

        # Get the list of sources separated by commas
        if self.args.sources != None:
            self.sources = self.args.sources
 
        payload = {"name": self.hostGroupName, "hostnames": [] }
        if self.sources != None:
            sourceList = str.split(self.sources,',')
            for s in sourceList:
                payload["hostnames"].append(s)
        self.data = payload
    


###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###
from plugin_base import PluginBase

class PluginAdd (PluginBase):
     
    def __init__(self):
        PluginBase.__init__(self)
        self.method = "PUT"
        self.path="v1/plugins/private"
        
        self.pluginName = None
        self.organizationName = None
        self.repositoryName = None
        
    def addArguments(self):
        PluginBase.addArguments(self)
        self.parser.add_argument('-o', '--organization-name', dest='organizationName',action='store',required=True,metavar="organization_name",
                                 help='Name of the github user or organization')
        self.parser.add_argument('-r', '--repository-name', dest='repositoryName',action='store',required=True,metavar="respository_name",
                                 help='Name of the github user or organization')

    def getArguments(self):
        '''
        Extracts the specific arguments of this CLI
        '''
        PluginBase.getArguments(self)
        if self.args.organizationName != None:
            self.organizationName = self.args.organizationName
        if self.args.repositoryName != None:
            self.repositoryName = self.args.repositoryName
            
        self.path = "v1/plugins/private/{0}/{1}/{2}".format(self.pluginName,self.organizationName,self.repositoryName)
         
    def getDescription(self):
        return "Imports a meter plugin from a github repository into a Boundary account"
    


###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###
from api_cli import ApiCli

class PluginGetComponents (ApiCli):
     
    def __init__(self):
        ApiCli.__init__(self)
        self.method = "GET"
        self.path="v1/plugins"
        self.pluginName = None
        
    def addArguments(self):
        ApiCli.addArguments(self)
        self.parser.add_argument('-n', '--plugin-Name', dest='pluginName',action='store',required=True,help='Plugin name')
        
    def getArguments(self):
        '''
        Extracts the specific arguments of this CLI
        '''
        ApiCli.getArguments(self)
        if self.args.pluginName != None:
            self.pluginName = self.args.pluginName
             
        self.path = "v1/plugins/{0}/components".format(self.pluginName)
         
    def getDescription(self):
        return "Get the components of a plugin in a Boundary account"
    


#!/usr/bin/env python
###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###

import argparse
import logging
import os
import requests
import urllib2
import json


'''
Base class for all the Boundary CLI commands
'''
class ApiCli():

  def __init__(self):
    self.logLevel = None
    self.message = None
    self.path = None
    self.apihost = "premium-api.boundary.com"
    self.email = None
    self.apitoken = None
    self.parser = argparse.ArgumentParser(description=self.getDescription())
    self.scheme = "https"
    self.path = None
    self.url_parameters = None
    self.method = "GET"
    self.headers = None
    self.data = None
    
    # Construct a dictionary with each of the HTTP methods that we support
    self.methods = {"DELETE": self.doDelete,"GET": self.doGet,"POST": self.doPost,"PUT": self.doPut}
    self.levels = {"debug": logging.DEBUG,
                   "info": logging.INFO,
                   "warn": logging.WARN,
                   "error": logging.ERROR,
                   "critical": logging.CRITICAL}

  def getDescription(self):
    '''
    Returns a description of the CLI
    '''
    return "General API CLI"

  def getEnvironment(self):
    '''
    Gets the configuration stored in environment variables
    '''
    try:
      self.email = os.environ['BOUNDARY_EMAIL']
    except(KeyError):
      self.email = None
    try:
      self.apitoken = os.environ['BOUNDARY_API_TOKEN']
    except(KeyError):
      self.apitoken = None
    try:
      self.apihost = os.environ['BOUNDARY_API_HOST']
    except(KeyError):
      self.apihost = 'premium-api.boundary.com'

  def addArguments(self):
    '''
    Configure handling of command line arguments.
    '''
    self.parser.add_argument('-l', '--log-level',dest='logLevel', action='store',choices=['debug','info','warning','error','critical'],
                             help='Sets logging level to one of debug,info,warning,error,critical. Default is logging is disabled')
    self.parser.add_argument('-a', '--api-host',dest='apihost',action='store',metavar="api_host",help='Boundary API host endpoint')
    self.parser.add_argument('-e', '--email',dest='email',action='store',metavar="e_mail",
                             help='e-mail that has access to the Boundary account')
    self.parser.add_argument('-t', '--api-token',dest='apitoken',required=False,action='store',metavar="api_token",
                             help='API token for given e-mail that has access to the Boundary account')
    
  def parseArgs(self):
    '''
    Handles the parse of the command line arguments
    '''
    self.addArguments()
    self.args = self.parser.parse_args()
    
  def configureLogging(self):
    '''
    Configure logging based on command line options
    '''
    if self.args.logLevel != None:
        logging.basicConfig(level=self.levels[self.args.logLevel])
        logging.info("Set logging level to {0}".format(self.args.logLevel))

  def getArguments(self):
    '''
    CLIs get called back so that they can process any command line arguments
    that are given. This method handles the standard command line arguments for:
    API Host, user, password, etc.
    '''
    self.configureLogging()
    
    if self.args.apihost != None:
        self.apihost = self.args.apihost
    if self.args.email != None:
        self.email = self.args.email
    if self.args.apitoken != None:
        self.apitoken = self.args.apitoken
        
    logging.debug("apihost: {0}".format(self.apihost))
    logging.debug("email: {0}".format(self.email))
    logging.debug("apitoken: {0}".format(self.apitoken))
      
  def setErrorMessage(self,message):
        self.message = message
      
  def validateArguments(self):
    if self.email == None:
        self.setErrorMessage("E-mail for the account not provided")
        return False
    if self.apitoken == None:
        self.setErrorMessage("API Token for the account not provided")
        return False
    return True

  def getUrlParameters(self):
    urlParameters = ""
    if self.url_parameters != None:
        urlParameters = "?"
        values = self.url_parameters
        first = True
        for key in values:
            if first == True:
                first = False
            else:
                urlParameters = urlParameters + "&"
            urlParameters = urlParameters + "{0}={1}".format(key,values[key])
    return urlParameters
    
  def getPayload(self):
    if self.data == None:
        payload = None
    else:
        payload = json.dumps(self.data)
        logging.debug(payload)

    return payload

  def doGet(self):
    '''
    HTTP Get Request
    '''
    return requests.get(self.url,data=self.getPayload(),headers=self.headers,auth=(self.email,self.apitoken))

  def doDelete(self):
    '''
    HTTP Delete Request
    '''
    return requests.delete(self.url,data=self.getPayload(),headers=self.headers,auth=(self.email,self.apitoken))

  def doPost(self):

    return requests.post(self.url,data=self.getPayload(),headers=self.headers,auth=(self.email,self.apitoken))

  def doPut(self):
    '''
    HTTP Put Request
    '''
    return requests.put(self.url,data=self.getPayload(),headers=self.headers,auth=(self.email,self.apitoken))

  def callAPI(self):
    '''
    Make an API call to get the metric definition
    '''

    self.url = "{0}://{1}/{2}{3}".format(self.scheme,self.apihost,self.path,self.getUrlParameters())

    result = self.methods[self.method]()
    if result.status_code != urllib2.httplib.OK:
        logging.error(self.url)
        logging.error(self.method)
        if self.getPayload() != None:
            logging.error(self.getPayload())
        logging.error(result)
    self.handleResults(result)
      
  def handleResults(self,result):
    '''
    Call back function to be implemented by the CLI.
    Default is to just print the results to standard out
    '''
    print(result.text)
  
  def execute(self):
    '''
    Run the steps to execute the CLI
    '''
    self.getEnvironment()
    self.parseArgs()
    self.getArguments()
    if self.validateArguments() == True:
        self.callAPI()
    else:
        print(self.message)




###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###
from api_cli import ApiCli

class AlarmCreate (ApiCli):
     
    def __init__(self):
        ApiCli.__init__(self)
        self.method = "POST"
        
        self.alarmName = None
        self.metricName = None
        self.aggregate = None
        self.operation = None
        self.resolution = None
        self.isDisabled = False
        
        self.intervals = {"1 second": 1,
                          "15 seconds": 15,
                          "1 minute": 60,
                          "5 minutes": 900,
                          "1 hour": 3600}
        
        
    def addArguments(self):
        ApiCli.addArguments(self)
        self.parser.add_argument('-n', '--alarm-name', dest='alarmName',action='store',required=True,
                                 metavar='alarm_name',help='Name of the alarm')
        self.parser.add_argument('-m', '--metric', dest='metricName',action='store',
                                 metavar='display_name',help='Name of the metric to alarm')
        self.parser.add_argument('-g', '--trigger-aggregate', dest='aggregate',action='store',choices=['sum','avg','max','min'],
                                 metavar='aggregate',help='Metric aggregate to alarm upon')
        self.parser.add_argument('-o', '--trigger-operation', dest='operation',action='store',choices=['eq','gt','lt'],
                                 metavar='operation',help='Trigger threshold comparison')
        self.parser.add_argument('-v', '--trigger-threshold', dest='triggerThreshold',action='store',metavar='value',help='Trigger threshold value')
        self.parser.add_argument('-r', '--trigger-interval', dest='triggerInterval',action='store',required=True,
                                 choices=['1 second', '15 seconds', '1 minute', '5 minutes','1 hour'],
                                 metavar='interval',help='Interval to alarm on, can be one of: "1 second","15 seconds","1 minute","5 minutes","1 hour"')
        self.parser.add_argument('-i','--host-group-id',dest='hostGroupId',action='store',metavar='hostgroup_id',
                                 help='Host group the alarm applies to')
        self.parser.add_argument('-d','--note',dest='note',action='store',metavar='note',
                                 help='A description or resolution of the alarm')
        self.parser.add_argument('-p', '--per-host-notify', dest='pertHostNotify',action='store_true',
                                 help='An alarm by default will run the associated actions when any server in the host group violates the threshold, and then at the end when all servers are back within the threshold. If perHostNotify is set to true, the actions will run when ANY server in the group violates and falls back within the threshold.')
        self.parser.add_argument('-x', '--is-disabled',dest='isDisabled',action='store_true',help='Enable or disable the alarm')
        
    def getArguments(self):
        '''
        Extracts the specific arguments of this CLI
        '''
        ApiCli.getArguments(self)
        if self.args.metricName != None:
            self.metricName = self.args.metricName
            
        if self.args.displayName != None:
            self.displayName = self.args.displayName
        else:
            self.displayName = self.metricName
                        
        if self.args.displayNameShort != None:
            self.displayNameShort = self.args.displayNameShort
        else:
            self.displayNameShort = self.metricName
            
        if self.args.description != None:
            self.description = self.args.description
        else:
            self.description = self.metricName
                    
        if self.args.aggregate != None:
            self.aggregate = self.args.aggregate
        else:
            self.aggregate = "ave"
            
        if self.args.unit != None:
            self.unit = self.args.unit
        else:
            self.unit = "number"
            
        if self.args.resolution != None:
            self.resolution = self.args.resolution
        else:
            self.resolution = 1000
            
        if self.args.isDisabled != None:
            self.isDisabled = self.args.isDisabled
            
       
        self.data = {'name': self.metricName,
                    'displayName': self.displayName,
                    'displayNameShort': self.displayNameShort,
                    'description': self.description,
                    'defaultAggregate': self.aggregate,
                    'unit': self.unit,
                    'defaultResolutionMS': self.resolution,
                    'isDisabled': self.isDisabled}
        self.path = "v1/metrics/{0}".format(self.metricName)
    
    def validateArguments(self):
        return ApiCli.validateArguments(self)
         
    def getDescription(self):
        return "Creates a new metric definition in an Boundary account"
    


###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###
from host_group_modify import HostGroupModify

class HostGroupUpdate (HostGroupModify):
     
    def __init__(self):
        HostGroupModify.__init__(self,True)
        self.method = "PUT"
        
        self.hostGroupId = ""
        
    def addArguments(self):
        HostGroupModify.addArguments(self)
        self.parser.add_argument('-i', '--host-group-id', dest='hostGroupId',action='store',required=True,metavar='host_group_id',help='Host group id to update')
        
    def getArguments(self):
        '''
        Extracts the specific arguments of this CLI
        '''
        HostGroupModify.getArguments(self)
        
        if self.args.hostGroupId != None:
            self.hostGroupId = self.args.hostGroupId
                
        self.path="v1/hostgroup/" + str(self.hostGroupId)
         
    def getDescription(self):
        return "Updates host group definition in a Boundary account"
    


###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###
from host_group_modify import HostGroupModify

class HostGroupCreate (HostGroupModify):
     
    def __init__(self,update):
        HostGroupModify.__init__(self,False)
        self.path="v1/hostgroups"
        self.sources = None
                        
    def getDescription(self):
        return "Creates host group definition in a Boundary account"
    


#!/usr/bin/env python
###
### Copyright 2014-2015, Boundary
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###

import json
from pprint import pprint
import sys

'''
Reads and provides access to a plugin.json file the manifest of plugins.
'''
class PluginManifest():

  def __init__(self,path=None):
    '''
    Initialize the PluginManifest instance
    '''
    self.path = path
    self.manifest_json = None
    self.manifest = None
      
  def getMetricNames(self):
    '''
    Returns the list of metrics associated with the plugin manifest
    '''
    return self.manifest['metrics']

  def load(self):
    '''
    Load the metrics file from the given path
    '''
    f = open(self.path,"r")
    self.manifest_json = f.read()

  def parse(self):
    '''
    Parses the manifest JSON into a dictionary
    '''
    self.manifest = json.loads(self.manifest_json)

  def get(self):
    '''
    Read the JSON file and parse into a dictionary
    '''
    self.load()
    self.parse()

  def getManifest(self):
    '''
    Returns the dictionary from the parse JSON plugin manifest
    '''
    return self.manifest

if __name__ == "__main__":
  if len(sys.argv) != 2:
      sys.stderr.write("No file")
      sys.exit(1)
      
  p = PluginManifest(sys.argv[1])
  p.get()
  pprint(p.getManifest())
  pprint(p.getMetricNames())



###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###
from api_cli import ApiCli
import socket
import time
import requests

'''
Implements command line utility to add a measurement value to a Boundary account
Uses the following Boundary API:

http://premium-documentation.boundary.com/v1/post/measurements

'''
class MeasurementCreate (ApiCli):
     
    def __init__(self):
        ApiCli.__init__(self)
        self.method = "POST"
        self.path="v1/measurements"
        
        self.metricName = None
        self.measurement = None
        self.source = None
        self.timestamp = None
        
    def addArguments(self):
        ApiCli.addArguments(self)
        self.parser.add_argument('-n', '--metric-name', dest='metricName',action='store',required=True,metavar='metric_name',
                                 help='Metric identifier')
        self.parser.add_argument('-m', '--measurement', dest='measurement',action='store',required=True,metavar="measurement",
                                 help='Measurement value')
        self.parser.add_argument('-s', '--source', dest='source',action='store',metavar="source",
                                 help='Source of measurement. Defaults to the host where the command is run')
        self.parser.add_argument('-d', '--timestamp', dest='timestamp',action='store',metavar="timestamp",
                                 help='Time of occurrence of the measurement in either epoch seconds or epoch milliseconds. Defaults to the receipt time at Boundary')

    def getArguments(self):
        '''
        Extracts the specific arguments of this CLI
        '''
        ApiCli.getArguments(self)
        if self.args.metricName != None:
            self.metricName = self.args.metricName
            
        if self.args.measurement != None:
            self.measurement = self.args.measurement
            
        if self.args.source != None:
            self.source = self.args.source
        else:
            self.source = socket.gethostname()
            
        if self.args.timestamp != None:
            self.timestamp = self.args.timestamp
        else:
            self.timestamp = int(time.time())
            
        self.data = {"metric": self.metricName,"measure": self.measurement,"source": self.source,"timestamp": self.timestamp}
        self.headers = {'Content-Type': 'application/json',"Accept": "application/json"}
        
    def callAPI(self):
        '''
        Override so we can handle the incomplete read error generated
        by Boundary API that creates a measurement.
        Handle here instead of ApiCli since we do not want to mask errors
        to other API calls.
        '''
        try:
            ApiCli.callAPI(self)
        except requests.exceptions.ChunkedEncodingError:
            None
 
    def getDescription(self):
        return "Adds a measurement value to a Boundary account"
    



from distutils.core import setup
setup(
    name='boundary',
    version='0.0.7',
    url="https://github.com/boundary/boundary-api-cli",
    author='David Gwartney',
    author_email='davidg@boundary.com',
    packages=['boundary',],
    scripts=[
      'bin/alarm-create',
      'bin/alarm-list',
      'bin/action-installed',
      'bin/action-types',
      'bin/hostgroup-create',
      'bin/hostgroup-delete',
      'bin/hostgroup-get',
      'bin/hostgroup-list',
      'bin/hostgroup-update',
      'bin/measurement-create',
      'bin/measurement-get',
      'bin/metric-create',
      'bin/metric-delete',
      'bin/metric-export',
      'bin/metric-import',
      'bin/metric-list',
      'bin/metric-markdown',
      'bin/metric-ref',
      'bin/plugin-add',
      'bin/plugin-get',
      'bin/plugin-get-components',
      'bin/plugin-list',
      'bin/plugin-install',
      'bin/plugin-installed',
      'bin/plugin-remove',
      'bin/plugin-uninstall',
      'bin/relay-list',
      'bin/user-get',
    ],
    license='LICENSE.txt',
    description='Command line interface to Boundary REST APIs',
    long_description=open('README.txt').read(),
    install_requires=[
        "requests >= 2.3.0",
        "python-dateutil >= 2.4.1",
    ],
)




###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###
from api_cli import ApiCli
from dateutil import parser
from datetime import datetime

'''
Gets measurements from a Boundary account
'''
class MeasurementGet (ApiCli):
     
    def __init__(self):
        ApiCli.__init__(self)
        self.method = "GET"
        self.metricName = None
        self.source = None
        self.aggregate = None
        self.startTime = None
        self.stoptTime = None
        
    def addArguments(self):
    	'''
        Add specific command line arguments for this command   
        '''

	# Call our parent to add the default arguments
        ApiCli.addArguments(self)

        # Command specific arguments
        self.parser.add_argument('-n', '--name', dest='metricName',action='store',required=True,metavar="metric_name",help='Metric identifier')
        self.parser.add_argument('-g', '--aggregate', dest='aggregate',action='store',choices=['sum','avg','max','min'],metavar='aggregate',help='Metric default aggregate')
        self.parser.add_argument('-s', '--source', dest='source',action='store',metavar="source",help='Source of measurement')
        self.parser.add_argument('-b', '--start', dest='start',action='store',required=True,metavar="start",help='Start of time range')
        self.parser.add_argument('-d', '--end', dest='end',action='store',metavar="end",help='End of time range')

    def getArguments(self):
        '''
        Extracts the specific arguments of this CLI
        '''
        ApiCli.getArguments(self)
        if self.args.metricName != None:
            self.metricName = self.args.metricName
            
        if self.args.source != None:
            self.source = self.args.source
        else:
            self.source=""
            
        if self.args.aggregate != None:
            self.aggregate = self.args.aggregate
        else:
            self.aggregate = "avg"
        
        # The start time is a required argument on
        # the command line so self.start.args should never
        # have a value of None
        if self.args.start == None:
            startTime = int(datetime.now().strftime("%s"))
        else:
            startTime = int(self.parseTimeDate(self.args.start).strftime("%s"))
        
        # If the end time is not specified then
        # default to the current time
        if self.args.end == None:
            stopTime = int(datetime.now().strftime("%s"))
        else:
            stopTime = int(self.parseTimeDate(self.args.end).strftime("%s"))
        
        # Convert to epoch time in milli-seconds
        startTime = startTime * 1000
        stopTime = stopTime * 1000

        self.path = "v1/measurements/{0}".format(self.metricName)
        self.url_parameters = {"source": self.source, "start": str(startTime) ,"end": str(stopTime), "agg": self.aggregate }
        
    def parseTimeDate(self,s):
        '''
        Attempt to parse the passed in string into a valid datetime.
        If we get a parse error then assume the string is an epoch time
        and convert to a datetime.
        '''
        try:
            ret = parser.parse(s)
        except ValueError:
            try:
                ret = datetime.utcfromtimestamp(s)
            except TypeError:
                ret = None
        return ret
         
    def getDescription(self):
        '''
        Returns the description of this command
        '''
        return "Retrieves measurement values from a metric in a Boundary account"
    



###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###
from plugin_base import PluginBase

class PluginUninstall (PluginBase):
     
    def __init__(self):
        PluginBase.__init__(self)
        self.method = "DELETE"
        self.path = "v1/plugins/installed"
        self.removeMetrics = False
        self.removeDashes = False
        
    def addArguments(self):
        PluginBase.addArguments(self)
        self.parser.add_argument('-d', '--remove-Dashes', dest='removeDashes',action='store_true',help='Remove dashboards associated with the plugin')
        self.parser.add_argument('-r', '--remove-Metrics', dest='removeMetrics',action='store_true',help='Remove metrics associated with the plugin')

    def getArguments(self):
        PluginBase.getArguments(self)
        self.path = "v1/plugins/installed/{0}".format(self.pluginName)
        self.url_parameters = {"removeMetrics": self.removeMetrics,"removeDashes": self.removeDashes}
         
    def getDescription(self):
        return "Uninstalls a plugin from a Boundary account"
    


###
### Copyright 2014-2015 Boundary, Inc.
###
### Licensed under the Apache License, Version 2.0 (the "License");
### you may not use this file except in compliance with the License.
### You may obtain a copy of the License at
###
###     http://www.apache.org/licenses/LICENSE-2.0
###
### Unless required by applicable law or agreed to in writing, software
### distributed under the License is distributed on an "AS IS" BASIS,
### WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
### See the License for the specific language governing permissions and
### limitations under the License.
###
'''
Command line scripts for accessing the Boundary APIs
'''

import alarm_create
import alarm_list
import action_installed
import action_types
import api_cli
import host_group_create
import host_group_delete
import host_group_get
import host_group_list
import host_group_search
import host_group_update
import measurement_create
import measurement_get
import metric_create
import metric_delete
import metric_list
import metric_ref
import plugin_add
import plugin_get
import plugin_get_components
import plugin_install
import plugin_installed
import plugin_list
import plugin_remove
import plugin_uninstall
import plugin_list
import relay_list
import user_get
